==> rest-assured-1.7.2-sources.jar: com/jayway/restassured/internal/mapping/ObjectMapping.java <==
package com.jayway.restassured.internal.mapping;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class ObjectMapping
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static <T> T deserialize(com.jayway.restassured.response.ResponseBodyData response, java.lang.Class<T> cls, java.lang.String contentType, java.lang.String defaultContentType, java.lang.String charset, com.jayway.restassured.mapper.ObjectMapperType mapperType, com.jayway.restassured.config.ObjectMapperConfig objectMapperConfig) { return null;}
public static  java.lang.Object serialize(java.lang.Object object, java.lang.String contentType, java.lang.String charset, com.jayway.restassured.mapper.ObjectMapperType mapperType, com.jayway.restassured.config.ObjectMapperConfig config) { return null;}
public static  java.lang.Object parseWithJackson1(com.jayway.restassured.mapper.ObjectMapperDeserializationContext ctx, com.jayway.restassured.mapper.factory.Jackson1ObjectMapperFactory factory) { return null;}
public static  java.lang.Object parseWithJackson2(com.jayway.restassured.mapper.ObjectMapperDeserializationContext ctx, com.jayway.restassured.mapper.factory.Jackson2ObjectMapperFactory factory) { return null;}
}

==> rest-assured-2.3.3-sources.jar: com/jayway/restassured/internal/mapping/ObjectMapping.java <==
package com.jayway.restassured.internal.mapping;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class ObjectMapping
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static <T> T deserialize(com.jayway.restassured.response.ResponseBodyData response, java.lang.Class<T> cls, java.lang.String contentType, java.lang.String defaultContentType, java.lang.String charset, com.jayway.restassured.internal.mapper.ObjectMapperType mapperType, com.jayway.restassured.config.ObjectMapperConfig objectMapperConfig) { return null;}
public static  java.lang.String serialize(java.lang.Object object, java.lang.String contentType, java.lang.String charset, com.jayway.restassured.internal.mapper.ObjectMapperType mapperType, com.jayway.restassured.config.ObjectMapperConfig config) { return (java.lang.String)null;}
public static  java.lang.Object parseWithJackson1(com.jayway.restassured.mapper.ObjectMapperDeserializationContext ctx, com.jayway.restassured.mapper.factory.Jackson1ObjectMapperFactory factory) { return null;}
public static  java.lang.Object parseWithJackson2(com.jayway.restassured.mapper.ObjectMapperDeserializationContext ctx, com.jayway.restassured.mapper.factory.Jackson2ObjectMapperFactory factory) { return null;}
}
